@@ -40,12 +40,25 @@ def init_git_repo(target):
 
 def create_git_repo(target, msg):
     init_git_repo(target)
-    subprocess.check_call(['git', 'add', '*'], cwd=target)
-    if sys.platform == "win32":
-        # prevent this:
-        # bash: line 1: ./ci_support/run_docker_build.sh: Permission denied
-        # ./ci_support/run_docker_build.sh returned exit code 126
-        subprocess.check_call(['git', 'update-index', '--chmod=+x', 'ci_support/run_docker_build.sh'], cwd=target)
+    subprocess.check_call(['git', 'add', '-A'], cwd=target)
+
+    # Ensure shell scripts have executable permissions.
+    executable_files = [
+        "ci_support/checkout_merge_commit.sh",
+        "ci_support/run_docker_build.sh",
+    ]
+    for each_executable_file in executable_files:
+        if os.path.exists(os.path.join(target, each_executable_file)):
+            subprocess.check_call(
+                [
+                    'git',
+                    'update-index',
+                    '--chmod=+x',
+                    each_executable_file
+                ],
+                cwd=target
+            )
+
     subprocess.check_call(['git', 'commit', '-m', msg], cwd=target)
 
 
@@ -179,16 +192,53 @@ class Regenerate(Subcommand):
         scp = self.subcommand_parser
         scp.add_argument("--feedstock_directory", default=os.getcwd(),
                          help="The directory of the feedstock git repository.")
+        scp.add_argument("-c", "--commit", nargs='?', choices=["edit", "auto"], const="edit",
+                         help="Whether to setup a commit or not.")
 
     def __call__(self, args):
         try:
             configure_feedstock.main(args.feedstock_directory)
-            print("\nCI support files regenerated. These need to be pushed to github!")
-            print("\nYou can commit the changes with:\n\n"
-                  "    git add -A\n"
-                  "    git commit -m 'MNT: Re-rendered with conda-smithy %s'" % __version__)
+            print("\nRe-rendered with conda-smithy %s.\n" % __version__)
+
+            is_git_repo = os.path.exists(os.path.join(args.feedstock_directory, ".git"))
+            if is_git_repo:
+                has_staged_changes = subprocess.call(
+                    [
+                        "git", "diff", "--cached", "--quiet", "--exit-code"
+                    ],
+                    cwd=args.feedstock_directory
+                )
+                if has_staged_changes:
+                    if args.commit:
+                        git_args = [
+                            'git',
+                            'commit',
+                            '-m',
+                            'MNT: Re-rendered with conda-smithy %s' % __version__
+                        ]
+                        if args.commit == "edit":
+                            git_args += [
+                                '--edit',
+                                '--status',
+                                '--verbose'
+                            ]
+                        subprocess.check_call(
+                            git_args,
+                            cwd=args.feedstock_directory
+                        )
+                        print("")
+                    else:
+                        print(
+                            "You can commit the changes with:\n\n"
+                            "    git commit -m 'MNT: Re-rendered with conda-smithy %s'\n" % __version__
+                        )
+                    print("These changes need to be pushed to github!\n")
+                else:
+                    print("No changes made. This feedstock is up-to-date.\n")
         except RuntimeError as e:
             print(e)
+        except subprocess.CalledProcessError as e:
+            print(e)
 
 
 class RecipeLint(Subcommand):
